#ifdef PIXEL
extern float time;
extern vec2 position;
extern vec2 resolution;
extern int automove = 0;

// Star Nest by Pablo Román Andrioli
// Modified a lot.
// Translated from pure GLSL to Love2D's effect code by daneos

// This content is under the MIT License.

#define iterations 14
#define formuparam 0.530

#define volsteps 8
#define stepsize 0.050

#define zoom   2.
#define tile   0.850
#define speed  0.0001

#define brightness 0.0015
#define darkmatter 0.400
#define distfading 0.760
#define saturation 0.800

#define move_speed 3700.


vec4 effect(vec4 color, Image tex, vec2 tc, vec2 pc)
{
	//get coords and direction
	vec2 uv=pc/resolution;
	uv.y*=resolution.y/resolution.x;
	vec3 dir=vec3(uv*zoom,1.);
	
	float a2=time*speed+.25;
	float a1=0.0;
	mat2 rot1=mat2(cos(a1),sin(a1),-sin(a1),cos(a1));
	mat2 rot2=mat2(cos(a2),sin(a2),-sin(a2),cos(a2));
	dir.xz*=rot1;
	dir.xy*=rot2;
	
	//from.x-=time;
	//position movement
	vec3 from=vec3(0.,0.,0.);
	if(automove == 1)
	{
		from.y+=time*0.01;
	}
	from.x+=position.x/move_speed;
	from.y-=position.y/move_speed;
	
	from.xz*=rot1;
	from.xy*=rot2;
	
	//volumetric rendering
	float s=0.1,fade=1.;
	vec3 v=vec3(0.);
	for(int r=0; r<volsteps; r++)
	{
		vec3 p=from+s*dir*.5;
		p = abs(vec3(tile)-mod(p,vec3(tile*2.))); // tiling fold
		float pa,a=pa=0.;
		for(int i=0; i<iterations; i++)
		{ 
			p=abs(p)/dot(p,p)-formuparam; // the magic formula
			a+=abs(length(p)-pa); // absolute sum of average change
			pa=length(p);
		}
		float dm=max(0.,darkmatter-a*a*.001); //dark matter
		a*=a*a*2.; // add contrast
		if (r>3) fade*=1.-dm; // dark matter, don't render near
		//v+=vec3(dm,dm*.5,0.);
		v+=fade;
		v+=vec3(s,s*s,s*s*s*s)*a*brightness*fade; // coloring based on distance
		fade*=distfading; // distance fading
		s+=stepsize;
	}
	v=mix(vec3(length(v)),v,saturation); //color adjust
	return vec4(v*.01,color.a);	
}
#endif
